@@ -33,7 +33,7 @@ impl Timer {
         if as_nanoseconds(&self.last_display.elapsed()) > NANOS_PER_SEC {
             self.last_display = Instant::now();
             let average = (self.duration as f32) / (self.invocations as f32);
-            let max_tps = NANOS_PER_SEC / (average as u64);
+            let max_tps = NANOS_PER_SEC / (average as u64).max(1);
             trace!("{:16}: {:4} / {:7} tps | {:7.0} ns", self.label, self.invocations, max_tps, average);
             self.duration = 0;
             self.invocations = 0;
